import {
  BarcodeScanner,
  ReaderType,
  CodeValidatorCallback
} from "./barcode-scanner";
class BarcodeScannerBuilder {
  _domTarget;
  _readerTypes = [];
  _autoCss = false;
  _resultImages = false;
  _codeValidator;
  _drawLocatedStyle;
  _drawDetectedStyle;
  _drawScanlineStyle;
  constructor(domTarget) {
    this._domTarget = domTarget;
  }
  addReader(readerType) {
    this._readerTypes.push(readerType);
    return this;
  }
  withAutoCss(enabled = true) {
    this._autoCss = enabled;
    return this;
  }
  withResultImages(enabled = true) {
    this._resultImages = enabled;
    return this;
  }
  withCodeValidator(callback) {
    this._codeValidator = callback;
    return this;
  }
  withDrawLocated(enabled = true, color = "green", width = 2) {
    if (enabled) {
      this._drawLocatedStyle = {color, lineWidth: width};
    }
    return this;
  }
  withDrawDetected(enabled = true, color = "#00F", width = 2) {
    if (enabled) {
      this._drawDetectedStyle = {color, lineWidth: width};
    }
    return this;
  }
  withDrawScanline(enabled = true, color = "red", width = 3) {
    if (enabled) {
      this._drawScanlineStyle = {color, lineWidth: width};
    }
    return this;
  }
  build() {
    if (this._readerTypes.length === 0) {
      this._readerTypes.push(ReaderType.CODE_128);
    }
    return new BarcodeScanner(this);
  }
  get domTarget() {
    return this._domTarget;
  }
  get readerTypes() {
    return this._readerTypes;
  }
  get autoCss() {
    return this._autoCss;
  }
  get resultImages() {
    return this._resultImages;
  }
  get codeValidator() {
    return this._codeValidator;
  }
  get drawLocatedStyle() {
    return this._drawLocatedStyle;
  }
  get drawDetectedStyle() {
    return this._drawDetectedStyle;
  }
  get drawScanlineStyle() {
    return this._drawScanlineStyle;
  }
}
export {
  BarcodeScannerBuilder
};
//# sourceMappingURL=barcode-scanner-builder.js.map
